# aconnection

[![Supported Versions](https://img.shields.io/badge/coverage-100%25-green)](https://shields.io/)
[![Supported Versions](https://img.shields.io/badge/poetry-✅-grey)](https://shields.io/)
[![Supported Versions](https://img.shields.io/badge/async-✅-grey)](https://shields.io/)
[![Supported Versions](https://img.shields.io/badge/pyrefly-✅-grey)](https://shields.io/)

---

**aconnection** - providers the following abc classes:
- Sync:
  - Closeable
  - Connectable
  - ResourceManager
  - ConnectionManager
- Async:
  - AsyncCloseable
  - AsyncConnectable
  - AsyncResourceManager
  - AsyncConnectionManager

---
